==> hk2-runlevel-2.2.0-b18-sources.jar: org/glassfish/hk2/runlevel/internal/CurrentTaskFutureWrapper.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2.runlevel.internal;

import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.glassfish.hk2.runlevel.RunLevelFuture;

/**
 * This object is used to wrap the internal CurrentTaskFuture which
 * is a ChangeableRunLevelFuture.  This way the users of the
 * RunLevelController API will not get something that can be
 * cast to a ChangeableRunLevelFuture
 * 
 * @author jwells
 */
public class CurrentTaskFutureWrapper implements RunLevelFuture {
    private final CurrentTaskFuture delegate;
    
    /* package */ CurrentTaskFutureWrapper(CurrentTaskFuture delegate) {
        this.delegate = delegate;
    }

    @Override
    public boolean isCancelled() {
        return delegate.isCancelled();
    }

    @Override
    public boolean isDone() {
        return delegate.isDone();
    }

    @Override
    public Object get() throws InterruptedException, ExecutionException {
        return delegate.get();
    }

    @Override
    public Object get(long timeout, TimeUnit unit)
            throws InterruptedException, ExecutionException,
            TimeoutException {
        return delegate.get(timeout, unit);
    }

    @Override
    public int getProposedLevel() {
        return delegate.getProposedLevel();
    }

    @Override
    public boolean isUp() {
        return delegate.isUp();
    }

    @Override
    public boolean isDown() {
        return delegate.isDown();
    }

    @Override
    public boolean cancel(boolean mayInterruptIfRunning) {
        return delegate.cancel(mayInterruptIfRunning);
    }
    
    /* package */ CurrentTaskFuture getDelegate() {
        return delegate;
    }

}

==> hk2-runlevel-2.5.0-sources.jar: org/glassfish/hk2/runlevel/internal/CurrentTaskFutureWrapper.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.hk2.runlevel.internal;

import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.glassfish.hk2.runlevel.RunLevelFuture;

/**
 * This object is used to wrap the internal CurrentTaskFuture which
 * is a ChangeableRunLevelFuture.  This way the users of the
 * RunLevelController API will not get something that can be
 * cast to a ChangeableRunLevelFuture
 * 
 * @author jwells
 */
public class CurrentTaskFutureWrapper implements RunLevelFuture {
    private final CurrentTaskFuture delegate;
    
    /* package */ CurrentTaskFutureWrapper(CurrentTaskFuture delegate) {
        this.delegate = delegate;
    }

    @Override
    public boolean isCancelled() {
        return delegate.isCancelled();
    }

    @Override
    public boolean isDone() {
        return delegate.isDone();
    }

    @Override
    public Object get() throws InterruptedException, ExecutionException {
        return delegate.get();
    }

    @Override
    public Object get(long timeout, TimeUnit unit)
            throws InterruptedException, ExecutionException,
            TimeoutException {
        return delegate.get(timeout, unit);
    }

    @Override
    public int getProposedLevel() {
        return delegate.getProposedLevel();
    }

    @Override
    public boolean isUp() {
        return delegate.isUp();
    }

    @Override
    public boolean isDown() {
        return delegate.isDown();
    }

    @Override
    public boolean cancel(boolean mayInterruptIfRunning) {
        return delegate.cancel(mayInterruptIfRunning);
    }
    
    /* package */ CurrentTaskFuture getDelegate() {
        return delegate;
    }
    
    @Override
    public String toString() {
        return "CurrentTaskFutureWrapper(" + delegate.toString() + "," + System.identityHashCode(this ) + ")";
    }

}
